/*

  Copyright (c) 2003-2004 Linus Brolin.

    This software is provided 'as-is', without any express or implied
    warranty.  In no event will the authors be held liable for any damages
    arising from the use of this software.

    Permission is granted to anyone to use this software for any purpose,
    including commercial applications, and to alter it and redistribute it
    freely, subject to the following restrictions:

    1. The origin of this software must not be misrepresented; you must not
       claim that you wrote the original software. If you use this software
       in a product, an acknowledgment in the product documentation would be
       appreciated but is not required.
    2. Altered source versions must be plainly marked as such, and must not be
       misrepresented as being the original software.
    3. This notice may not be removed or altered from any source distribution.


  Linus Brolin
  linus.b@home.se

*/

/*-----------------------------------------------------------------------------
  Image Viewer v1.2
  ~~~~~~~~~~~~~~~~~
  This script creates an image viewer that slides through a number of images,
  showing one at a time, with the click of a button.

  Usage:
    All images should be named pic<num> in the elements, starting with pic1.
      <bitmap id="pic1" file="images/picture 1.png"/>
      <bitmap id="pic2" file="images/picture 2.png"/>
      <bitmap id="pic3" file="images/picture 3.png"/>

    You'll need two layers and two buttons for this script to work without
    modifying it.
    The layers should be called "backpic" and "frontpic" and be placed in the
    order as shown below:
      <layer id="backpic" x="0" y="0" image="pic2"/>
      <layer id="frontpic" x="0" y="0" image="pic1"/>
    !THEIR PLACEMENT IS IMPORTANT!

    The buttons can be placed pretty much anywhere, without having to modify
    the script, but the need to be called "Prev" and "Next".
      <button id="Prev" x="10" y="10" image="prev" downImage="prev.down"/>
      <button id="Next" x="20" y="10" image="next" downImage="next.down"/>

    Finally, you'll need to put this script line at the end of the group or
    layout you're working in. Be sure that none of the buttons or layers
    above are located in a parent to the chosen layout or group.
    If you're unsure, just place this line at the bottom of the layout and it
    "should" be fine.
    Change the param to the number of images in your "gallery".
      <script id="ImageViewer" file="scripts/imageviewer.maki" param="3"/>

  by Plague (Linus Brolin)
-----------------------------------------------------------------------------*/

#include <lib/std.mi>

Global Button prevImage, nextImage;
Global Layer backpic, frontpic;
Global Int imgnum, maximgnum;

System.onScriptUnLoading() {
  setprivateint("D-Reliction","image number",imgnum);
}

System.onScriptLoaded() {
  Group pgroup = getScriptGroup();
  prevImage = pgroup.findobject("Prev");
  nextImage = pgroup.findobject("Next");
  backpic = pgroup.findobject("backpic");
  frontpic = pgroup.findobject("frontpic");

  String param = getParam();
  maximgnum = stringToInteger(getToken(param, ",", 0));

  imgnum = getprivateint("D-Reliction","image number",1);
  frontpic.setxmlparam("image", "pic" + integerToString(imgnum));
}

prevImage.onLeftClick() {
  imgnum--;
  if (imgnum < 1) imgnum = maximgnum;

  backpic.setxmlparam("image", frontpic.getXmlParam("image"));
  frontpic.setAlpha(0);
  frontpic.setxmlparam("image", "pic" + integerToString(imgnum));
  frontpic.setTargetA(255);
  frontpic.setTargetSpeed(1);
  frontpic.gotoTarget();
}

nextImage.onLeftClick() {
  imgnum++;
  if (imgnum > maximgnum) imgnum = 1;

  backpic.setxmlparam("image", frontpic.getXmlParam("image"));
  frontpic.setAlpha(0);
  frontpic.setxmlparam("image", "pic" + integerToString(imgnum));
  frontpic.setTargetA(255);
  frontpic.setTargetSpeed(1);
  frontpic.gotoTarget();
}
