/*

  Copyright (c) 2003-2004 Linus Brolin.

    This software is provided 'as-is', without any express or implied
    warranty.  In no event will the authors be held liable for any damages
    arising from the use of this software.

    Permission is granted to anyone to use this software for any purpose,
    including commercial applications, and to alter it and redistribute it
    freely, subject to the following restrictions:

    1. The origin of this software must not be misrepresented; you must not
       claim that you wrote the original software. If you use this software
       in a product, an acknowledgment in the product documentation would be
       appreciated but is not required.
    2. Altered source versions must be plainly marked as such, and must not be
       misrepresented as being the original software.
    3. This notice may not be removed or altered from any source distribution.


  Linus Brolin
  linus.b@home.se

*/

/*-----------------------------------------------------------------------------
  visualization.m

  by Plague (Linus Brolin)
-----------------------------------------------------------------------------*/

#include <lib/std.mi>

#define NUM_VIS 20

Function setVis(int num);
Function setRegionVis(int num);
Function UpdateRegionVis(Layer eq, Map eqmap, Int value);

Global Map roundedVisMap, drelictionVisMap, headphonesVisMap, classicalVisMap, drdiscoVisMap, solid1VisMap, solid2VisMap;
Global Map daydreamerVisMap, frankyVisMap, hazardousVisMap, hifiVisMap, invadersVisMap, singingVisMap, stripVisMap, thrillerVisMap, zillaVisMap;
Global Timer VisTimer, AnimTimer;
Global GuiObject viscover;
Global Vis visdef, mirrorVis1, mirrorVis2;
Global Group standardVis, beatVis, regionBeat, mirroredVis;
Global Layer beatLayer;
Global AnimatedLayer lcdAnim;
Global Popupmenu SwitcherMenu;
Global Int currentVis, choice;
Global Double Level;

System.onScriptLoaded() {
  Group pgroup = getScriptGroup();
  standardVis = pgroup.findObject("Standard Vis");
  mirroredVis = pgroup.findObject("Mirrored Double Vis");
  regionBeat = pgroup.findObject("Region Beat Vis");
  viscover = pgroup.findObject("Vis-Cover");
  visdef = pgroup.findObject("vis");
  mirrorVis1 = pgroup.findObject("mirrorVis1");
  mirrorVis2 = pgroup.findObject("mirrorVis2");
  beatLayer = pgroup.findObject("Beat Layer");
  lcdAnim = pgroup.findObject("LCD Anim");

  roundedVisMap = new Map;
  roundedVisMap.loadMap("player.map.roundedvis");
  drelictionVisMap = new Map;
  drelictionVisMap.loadMap("player.map.d-relictionvis");
  headphonesVisMap = new Map;
  headphonesVisMap.loadMap("player.map.headphonesvis");
  classicalVisMap = new Map;
  classicalVisMap.loadMap("player.map.classicalvis");
  drdiscoVisMap = new Map;
  drdiscoVisMap.loadMap("player.map.drdiscovis");
  solid1VisMap = new Map;
  solid1VisMap.loadMap("player.map.solid1vis");
  solid2VisMap = new Map;
  solid2VisMap.loadMap("player.map.solid2vis");
  daydreamerVisMap = new Map;
  daydreamerVisMap.loadMap("player.map.daydreamer");
  frankyVisMap = new Map;
  frankyVisMap.loadMap("player.map.franky");
  hazardousVisMap = new Map;
  hazardousVisMap.loadMap("player.map.hazardous area");
  hifiVisMap = new Map;
  hifiVisMap.loadMap("player.map.hi-fi");
  invadersVisMap = new Map;
  invadersVisMap.loadMap("player.map.invaders");
  singingVisMap = new Map;
  singingVisMap.loadMap("player.map.singing fred");
  stripVisMap = new Map;
  stripVisMap.loadMap("player.map.strip poker");
  thrillerVisMap = new Map;
  thrillerVisMap.loadMap("player.map.thriller");
  zillaVisMap = new Map;
  zillaVisMap.loadMap("player.map.zilla");

  VisTimer = new Timer;
  VisTimer.setDelay(50);
  VisTimer.start();

  AnimTimer = new Timer;
  AnimTimer.setDelay(400);

  SwitcherMenu = New PopupMenu;
  SwitcherMenu.addCommand("00 - Off",0,0,0);
  SwitcherMenu.addCommand("01 - D-Reliction Beat Visualizer",1,0,0);
  SwitcherMenu.addCommand("02 - Spectrum Analyzer",2,0,0);
  SwitcherMenu.addCommand("03 - Mirrored Double Spectrum Analyzer",3,0,0);
  SwitcherMenu.addCommand("04 - Oscilliscope",4,0,0);
  SwitcherMenu.addCommand("05 - Mirrored Double Oscilliscope",5,0,0);
  SwitcherMenu.addCommand("06 - Solid Beat Visualizer 1",6,0,0);
  SwitcherMenu.addCommand("07 - Solid Beat Visualizer 2",7,0,0);
  SwitcherMenu.addCommand("08 - Classical Beat Visualizer",8,0,0);
  SwitcherMenu.addCommand("09 - Rounded Beat Visualizer",9,0,0);
  SwitcherMenu.addCommand("10 - Headphones Beat Visualizer",10,0,0);
  SwitcherMenu.addCommand("11 - Dr. Disco Beat Visualizer",11,0,0);
  SwitcherMenu.addCommand("12 - Daydreamer Beat Visualizer",12,0,0);
  SwitcherMenu.addCommand("13 - Franky Beat Visualizer",13,0,0);
  SwitcherMenu.addCommand("14 - Hazardous Area Beat Visualizer",14,0,0);
  SwitcherMenu.addCommand("15 - Hi-Fi Beat Visualizer",15,0,0);
  SwitcherMenu.addCommand("16 - Invaders Beat Visualizer",16,0,0);
  SwitcherMenu.addCommand("17 - Singing Fred Beat Visualizer",17,0,0);
  SwitcherMenu.addCommand("18 - Strip Poker Beat Visualizer",18,0,0);
  SwitcherMenu.addCommand("19 - Thriller Beat Visualizer",19,0,0);
  SwitcherMenu.addCommand("20 - Zilla Beat Visualizer",20,0,0);

  currentVis = getPrivateInt("D-Reliction", "CurrentVis", 1);
  lcdAnim.play();
}

System.onScriptUnloading() {
  VisTimer.stop();
  delete VisTimer;
  delete AnimTimer;
  delete roundedVisMap;
  delete drelictionVisMap;
  delete headphonesVisMap;
  delete classicalVisMap;
  delete drdiscoVisMap;
  delete solid1VisMap;
  delete solid2VisMap;
  delete daydreamerVisMap;
  delete frankyVisMap;
  delete hazardousVisMap;
  delete hifiVisMap;
  delete invadersVisMap;
  delete singingVisMap;
  delete stripVisMap;
  delete thrillerVisMap;
  delete zillaVisMap;
  delete SwitcherMenu;
  setPrivateInt("D-Reliction","CurrentVis", currentVis);
}

lcdAnim.onPlay() {
  setVis(0);
  lcdAnim.gotoFrame(lcdAnim.getStartFrame());
}

lcdAnim.onStop() {
  AnimTimer.start();
}

AnimTimer.onTimer() {
  AnimTimer.stop();
  lcdAnim.hide();
  setVis(currentVis);
}

VisTimer.onTimer() {
  setRegionVis(currentVis);
}

viscover.OnLeftButtonDown(int x, int y) {
  if (currentVis >= 0 && currentVis < NUM_VIS) currentVis++;
  else if (currentVis == NUM_VIS) currentVis = 0;
  setVis(currentVis);
}

viscover.OnRightButtonUp(int x, int y) {
  for (int i = 0; i <= NUM_VIS; i++) SwitcherMenu.checkCommand(i, currentVis == i);
  choice = SwitcherMenu.popAtMouse();
  if (choice >= 0 && choice <= NUM_VIS) currentVis = choice;
  setVis(currentVis);
  Complete;
}

setVis(int num) {
  if (num == 0) {
    visdef.setMode(0);
    mirrorVis1.setMode(0);
    mirrorVis2.setMode(0);
    standardVis.hide();
    mirroredVis.hide();
    regionBeat.hide();
    lcdAnim.gotoFrame(lcdAnim.getEndFrame());
    lcdAnim.show();
  } else if (num == 2) {
    visdef.setMode(1);
    standardVis.show();
    mirroredVis.hide();
    regionBeat.hide();
    lcdAnim.hide();
  } else if (num == 3) {
    mirrorVis1.setMode(1);
    mirrorVis2.setMode(1);
    standardVis.hide();
    mirroredVis.show();
    regionBeat.hide();
    lcdAnim.hide();
  } else if (num == 4) {
    visdef.setMode(2);
    standardVis.show();
    mirroredVis.hide();
    regionBeat.hide();
    lcdAnim.hide();
  } else if (num == 5) {
    mirrorVis1.setMode(2);
    mirrorVis2.setMode(2);
    standardVis.hide();
    mirroredVis.show();
    regionBeat.hide();
    lcdAnim.hide();
  } else {
    setRegionVis(num);
    standardVis.hide();
    mirroredVis.hide();
    regionBeat.show();
    lcdAnim.hide();
  }
}

setRegionVis(int num) {
  Level = (getLeftVuMeter() + getRightVuMeter()) / 2;
  if (num == 1) UpdateRegionVis(beatLayer, drelictionVisMap, Level);
  else if (num == 6) UpdateRegionVis(beatLayer, solid1VisMap, Level);
  else if (num == 7) UpdateRegionVis(beatLayer, solid2VisMap, Level);
  else if (num == 8) UpdateRegionVis(beatLayer, classicalVisMap, Level);
  else if (num == 9) UpdateRegionVis(beatLayer, roundedVisMap, Level);
  else if (num == 10) UpdateRegionVis(beatLayer, headphonesVisMap, Level);
  else if (num == 11) UpdateRegionVis(beatLayer, drdiscoVisMap, Level);
  else if (num == 12) UpdateRegionVis(beatLayer, daydreamerVisMap, Level);
  else if (num == 13) UpdateRegionVis(beatLayer, frankyVisMap, Level);
  else if (num == 14) UpdateRegionVis(beatLayer, hazardousVisMap, Level);
  else if (num == 15) UpdateRegionVis(beatLayer, hifiVisMap, Level);
  else if (num == 16) UpdateRegionVis(beatLayer, invadersVisMap, Level);
  else if (num == 17) UpdateRegionVis(beatLayer, singingVisMap, Level);
  else if (num == 18) UpdateRegionVis(beatLayer, stripVisMap, Level);
  else if (num == 19) UpdateRegionVis(beatLayer, thrillerVisMap, Level);
  else if (num == 20) UpdateRegionVis(beatLayer, zillaVisMap, Level);
}

UpdateRegionVis(Layer eq, Map eqmap, Int value) {
  Region r = new Region;
  r.loadFromMap(eqmap, value, 1);
  eq.setRegion(r);
  delete r;
}
